pub struct ClientAsync {
pub method: MethodAsync,
pub instance: String,
}Expand description
An async client, containing all info needed to perform a fetch.
Fields
method: MethodAsyncMethod of fetching, all methods in ClientAsync are async methods.
instance: StringA valid Invidious instance url.
Implementations
Sourceimpl ClientAsync
impl ClientAsync
Sourcepub fn new(instance: String, method: MethodAsync) -> Self
pub fn new(instance: String, method: MethodAsync) -> Self
Creates new ClientAsync from a given instance and method.
Sourcepub fn set_instance(&mut self, instance: String)
pub fn set_instance(&mut self, instance: String)
Modifies the instance of the ClientAsync.
Sourcepub fn instance(self, instance: String) -> Self
pub fn instance(self, instance: String) -> Self
Takes ownership of the instance and returns a new, modifed ClientAsync with changed instance.
Sourcepub fn set_method(&mut self, method: MethodAsync)
pub fn set_method(&mut self, method: MethodAsync)
Modifies the method of the ClientAsync.
Sourcepub fn method(self, method: MethodAsync) -> Self
pub fn method(self, method: MethodAsync) -> Self
Takes ownership of the method and returns a new, modifed ClientAsync with changed method.