pub struct Stats {
pub version: String,
pub software: Software,
pub registrations: bool,
pub usage: Usage,
pub metadata: Metadata,
}Fields
version: Stringsoftware: Softwareregistrations: boolusage: Usagemetadata: MetadataTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Stats
impl<'de> Deserialize<'de> for Stats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PublicItems for Stats
impl PublicItems for Stats
Sourcefn from_str(s: String) -> Result<Self, InvidiousError>where
Self: Sized + DeserializeOwned,
fn from_str(s: String) -> Result<Self, InvidiousError>where
Self: Sized + DeserializeOwned,
Converts &str to Self.
Sourcefn fetch_sync<C: ClientSyncTrait>(
client: &C,
id: Option<&str>,
params: Option<&str>,
) -> Result<Self, InvidiousError>where
Self: Sized + DeserializeOwned,
fn fetch_sync<C: ClientSyncTrait>(
client: &C,
id: Option<&str>,
params: Option<&str>,
) -> Result<Self, InvidiousError>where
Self: Sized + DeserializeOwned,
Blocking function to fetch the json data and deserialising it into Self.
Sourcefn fetch_async<'life0, 'life1, 'life2, 'async_trait, C>(
client: &'life0 C,
id: Option<&'life1 str>,
params: Option<&'life2 str>,
) -> Pin<Box<dyn Future<Output = Result<Self, InvidiousError>> + Send + 'async_trait>>where
Self: Sized + DeserializeOwned + Send + 'async_trait,
C: 'async_trait + ClientAsyncTrait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn fetch_async<'life0, 'life1, 'life2, 'async_trait, C>(
client: &'life0 C,
id: Option<&'life1 str>,
params: Option<&'life2 str>,
) -> Pin<Box<dyn Future<Output = Result<Self, InvidiousError>> + Send + 'async_trait>>where
Self: Sized + DeserializeOwned + Send + 'async_trait,
C: 'async_trait + ClientAsyncTrait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Async function to fetch the json data and deserialising it into Self.
Sourcefn from_value(value: Value) -> Result<Self, InvidiousError>where
Self: Sized + DeserializeOwned,
fn from_value(value: Value) -> Result<Self, InvidiousError>where
Self: Sized + DeserializeOwned,
Converts Value to Self.